pub enum RequestType {
GetKeymap(bool),
SetLayerBinding(SetLayerBindingRequest),
CheckUnsavedChanges(bool),
SaveChanges(bool),
DiscardChanges(bool),
GetPhysicalLayouts(bool),
SetActivePhysicalLayout(u32),
MoveLayer(MoveLayerRequest),
}Variants
GetKeymap(bool)
SetLayerBinding(SetLayerBindingRequest)
CheckUnsavedChanges(bool)
SaveChanges(bool)
DiscardChanges(bool)
GetPhysicalLayouts(bool)
SetActivePhysicalLayout(u32)
MoveLayer(MoveLayerRequest)
Implementations
Sourceimpl RequestType
impl RequestType
Sourcepub fn merge<B>(
field: &mut Option<RequestType>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<RequestType>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.