pub struct SetLayerBindingRequest {
pub layer: i32,
pub key_position: i32,
pub binding: Option<BehaviorBinding>,
}Fields
layer: i32key_position: i32binding: Option<BehaviorBinding>Trait Implementations
Sourceimpl Clone for SetLayerBindingRequest
impl Clone for SetLayerBindingRequest
Sourcefn clone(&self) -> SetLayerBindingRequest
fn clone(&self) -> SetLayerBindingRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetLayerBindingRequest
impl Debug for SetLayerBindingRequest
Sourceimpl Default for SetLayerBindingRequest
impl Default for SetLayerBindingRequest
Sourceimpl Message for SetLayerBindingRequest
impl Message for SetLayerBindingRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetLayerBindingRequest
impl PartialEq for SetLayerBindingRequest
Sourcefn eq(&self, other: &SetLayerBindingRequest) -> bool
fn eq(&self, other: &SetLayerBindingRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetLayerBindingRequest